/* LED8x8_MAX7219_SPI
 *  
 * 8x8-as LED mátrix kipróbálása MAX7219 meghajtással
 * Az inicializálás után két bitképet felváltva villogtatunk
 * A MAX7219 vezérlése ebben a programban szoftveres SPI 
 * meghajtással történik, ezért bármelyik digitális kivezetés 
 * felhasználható.
 */

const int SPI_CS  = 10;                   //SPI Chip Select jel (LED CS bemenetre
const int SPI_DIN = 12;                   //SPI MOSI adatvonal  (LED DIN bemenetre)
const int SPI_CLK = 11;                   //SPI CLK órajel      (LED CLK bemenetre)
  
const unsigned char led1[]= {
  0xFF,0x00,0x30,0x48,0x90,0x90,0x48,0x30};  //Iv 
const unsigned char led2[]= {
  0xFF,0x18,0x18,0xFF,0x00,0xF8,0xA8,0xA8};  //HE


void setup() {
  pinMode(SPI_CS,OUTPUT);                 //SPI_CS kimenet inicializálása
  digitalWrite(SPI_CS,HIGH);
  pinMode(SPI_CLK,OUTPUT);                //SPI_CLK kimenet inicializálása
  digitalWrite(SPI_CLK,LOW);  
  pinMode(SPI_DIN,OUTPUT);                //SPI_DIN kimenet inicializálása
  digitalWrite(SPI_DIN,LOW);   
  Init_MAX7219();                         //LED vezérlő bekonfigurálása
}

void loop (){
  for(int i=0; i<8; i++)                  //Első karakter (8 sor) kiírása 
    SPI_Write2(i+1,led1[i]);              // Figyelj a regisztercím eltolásra!
  delay(1000);                            //1 s várakozása  
  for(int i=0; i<8; i++)                  //Második karakter (8 sor) kiírása
    SPI_Write2(i+1,led2[i]);              // Figyelj a regisztercím eltolásra!
  delay(1000);                            //1 s várakozása 
}

/* Két bájt kiküldése */
void SPI_Write2(unsigned char MSB, unsigned char LSB) {
  digitalWrite(SPI_CS,LOW);               // CS aktiválás
  shiftOut(SPI_DIN,SPI_CLK,MSBFIRST,MSB); // SW SPI adatküldés 1. 
  shiftOut(SPI_DIN,SPI_CLK,MSBFIRST,LSB); // SW SPI adatküldés 2.   
  digitalWrite(SPI_CS,HIGH);              // CS deaktiválás   
}

/* A LED vezérlő IC konfigurálása */
void Init_MAX7219(void) {
  SPI_Write2(0x09, 0x00);       //Dekódolást kikapcsolni
  SPI_Write2(0x0A, 0x08);       //Közepes fényerő beállítása
  SPI_Write2(0x0B, 0x07);       //Pásztázási korlát beállítása
  SPI_Write2(0x0C, 0x01);       //Megjelenítési mód beállítása
  SPI_Write2(0x0F, 0x0F);       //Display teszt engedélyezés
  delay(500);
  SPI_Write2(0x01, 0x00);       //0. sor törlése
  SPI_Write2(0x02, 0x00);       //1. sor törlése
  SPI_Write2(0x03, 0x00);       //2. sor törlése
  SPI_Write2(0x04, 0x00);       //3. sor törlése
  SPI_Write2(0x05, 0x00);       //4. sor törlése
  SPI_Write2(0x06, 0x00);       //5. sor törlése
  SPI_Write2(0x07, 0x00);       //6. sor törlése
  SPI_Write2(0x08, 0x00);       //7. sor törlése
  SPI_Write2(0x0F, 0x00);       //Display teszt tiltás  
  delay(500);
}
