/* LedControl_8x8
 * 
 * Egy 8x8-as LED mátrix kipróbálása MAX7219 meghajtással,
 * a LedControl programkönyvtár felhasználásával.
 * Az inicializálás után két bitképet felváltva villogtatunk.
 * A data tömb bővítésével és a külső for ciklus határának
 * módosításával a kijelezett bitképek száma bővíthető.
 * 
 * A MAX7219 vezérlése ebben a programban szoftveres SPI 
 * meghajtással történik, ezért bármelyik digitális kivezetés 
 * felhasználható.
 */
#include "LedControl.h"
/* A LedControl objektum példányosítása lc néven, 
 * hozzárendelése a felsorol lábakhoz az alábbi
 * sorrendben: MOSI, CLK, CS. 
 * A negyedik paraméter a felfűzött MAX7219/21
 * modulok száma.
 */
LedControl lc = LedControl(12, 11, 10, 1);

const unsigned char data[2][8]= {
  {0xFF,0x00,0x30,0x48,0x90,0x90,0x48,0x30},  //Iv 
  {0xFF,0x18,0x18,0xFF,0x00,0xF8,0xA8,0xA8}   //HE
};

unsigned long delaytime = 1500;  // Késleltetés a kiírások között

void setup() {
  lc.shutdown(0, false);         // A kijelzés beindítása
  lc.setIntensity(0, 8);         // Közepes fényerő beállítása (0-15 a határ)
  lc.clearDisplay(0);            // Képernyő törlés
}

void loop() {
  for(int j=0; j<2; j++) {       // Végigmegyünk a bitképeken
    for(int i=0; i<8; i++) {     // Egy 8x8-as bitkép kirajzolása soronként
      lc.setRow(0,i,data[j][i]);
      delay(100);                // Egy kis lassítás a látványosság kedvéért...
    }  
    delay(delaytime);            // Várkozás a kiírások között
  }
}
